@@ -360,6 +360,8 @@ class Key:
 
 
 class Window:
+    never_minimize = ["Task Switching", "Cortana", ""]
+
     def __init__(self, hwnd=None):
         if hwnd is None:
             hwnd = win32gui.GetForegroundWindow()
@@ -393,14 +395,10 @@ class Window:
         cDC.BitBlt((0, 0), (w, h), dcObj, region[0], win32con.SRCCOPY)
         bmpinfo = dataBitMap.GetInfo()
         bmpstr = dataBitMap.GetBitmapBits(True)
-        return bmpstr, bmpinfo
-
-    def bitmap_to_image(self, bmpstr, bmpinfo):
-        im = Image.frombuffer(
+        return Image.frombuffer(
             'RGB',
             (bmpinfo['bmWidth'], bmpinfo['bmHeight']),
             bmpstr, 'raw', 'BGRX', 0, 1)
-        return im
 
     def click(self, x=None, y=None, button=Key.VK_LBUTTON, duration=.2):
         if x:
@@ -415,7 +413,7 @@ class Window:
         if win32gui.GetForegroundWindow() == self.hwnd:
             win32api.SetCursorPos((x, y))
         else:
-            win32gui.PostMessage(self.hwnd, win32con.WM_MOUSEMOVE, 0, l_param)
+            win32gui.PostMessage(self.hwnd, win32con.WM_MOUSEMOVE, None, l_param)
         self.mouse_down(button, l_param)
         time.sleep(duration)
         self.mouse_up(button, l_param)
@@ -461,16 +459,22 @@ class Window:
 
     def bring_to_front(self):
         front = Window()
-        while front.hwnd != self.hwnd:
+        if self.is_minimized:
+            win32gui.ShowWindow(self.hwnd, win32con.SW_RESTORE)
+        try:
+            win32gui.SetForegroundWindow(self.hwnd)
+            win32gui.ShowWindow(self.hwnd, win32con.SW_SHOW)
+        except:
             front.minimize()
-            try:
-                win32gui.SetForegroundWindow(self.hwnd)
-            except:
-                pass
-            front = Window()
+            self.bring_to_front()
 
     def minimize(self):
-        win32gui.ShowWindow(self.hwnd, win32con.SW_FORCEMINIMIZE)
+        if self.text not in self.never_minimize:
+            win32gui.ShowWindow(self.hwnd, win32con.SW_FORCEMINIMIZE)
+
+    @property
+    def is_minimized(self):
+        return win32gui.IsIconic(self.hwnd) != 0
 
     def press(self, key, duration=.1):
         self.key_down(key)
@@ -499,6 +503,3 @@ def rgbint2rgbtuple(rgb_int):
     green = (rgb_int >> 8) & 255
     blue = (rgb_int >> 16) & 255
     return red, green, blue
-
-
-
